# PKPM API

PKPM结构设计软件API，可以完成PKPM结构建模、PKPM结构计算结果提取等任务，详见[PKPM官方API文档](https://gitee.com/pkpmgh/pkpm-official---api-release "查看PKPM-API 用户手册")

## 安装

```bash
pip install pkpm_api
```

## 使用

```python
import APIPyInterface
# Use the API
```

### PKPM API的其他使用方式：

**1、使用AI大模型进行PKPM的二次开发（[PKPM-Agent](https://gitee.com/pkpmgh/PKPMAgentRelease "查看PKPM-Agent 用户手册")）**

- 🧩 **收藏AI对话生成的代码，复用以开发自定义功能**
- 🚀 **脚本执行器免环境配置，开箱即用**
- ⚡ **与PKPM打开工程共享进程，即改即生效**

**2、利用PKPM软件内置完整Python环境和您自己的IDE进行PKPM的二次开发**

- ⚙️ **简单配置即可使用，内置常用Python库**
- 💻 **包含pyi文件，支持语法高亮与代码补全**

